@@ -61,7 +61,7 @@ if TYPE_CHECKING:
 if AIRFLOW_V_3_0_PLUS:
     from airflow.sdk.execution_time.xcom import XCom
 else:
-    from airflow.models import XCom  # type: ignore[no-redef]
+    from airflow.models import XCom
 
 
 class DagIsPaused(AirflowException):
