@@ -27,12 +27,7 @@ from airflow.utils.log.logging_mixin import LoggingMixin
 
 if TYPE_CHECKING:
     from airflow.sdk.definitions._internal.node import DAGNode
-    from airflow.sdk.types import RuntimeTaskInstanceProtocol
-
-    if AIRFLOW_V_3_1_PLUS:
-        from airflow.sdk.types import Operator
-    else:
-        from airflow.models.operator import Operator
+    from airflow.sdk.types import Operator, RuntimeTaskInstanceProtocol
 
 # The key used by SkipMixin to store XCom data.
 XCOM_SKIPMIXIN_KEY = "skipmixin_key"
@@ -50,7 +45,7 @@ def _ensure_tasks(nodes: Iterable[DAGNode]) -> Sequence[Operator]:
         from airflow.sdk.definitions.mappedoperator import MappedOperator
     else:
         from airflow.models.baseoperator import BaseOperator  # type: ignore[no-redef]
-        from airflow.models.mappedoperator import MappedOperator  # type: ignore[no-redef]
+        from airflow.models.mappedoperator import MappedOperator
 
     return [n for n in nodes if isinstance(n, (BaseOperator, MappedOperator))]
 
